/****************************************************************************
*  Copyright (c) 2011 by Michael Fischer. All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
****************************************************************************
*  History:
*
*  22.05.2011  mifi  First Version for the SAM3U4E
****************************************************************************/
#define __VECTORS_SAM3S_C__

/*=========================================================================*/
/*  DEFINE: All extern Data                                                */
/*=========================================================================*/
extern unsigned long _estack;

/*=========================================================================*/
/*  DEFINE: Prototypes                                                     */
/*=========================================================================*/
void ResetHandler(void);

void NMI_Handler (void) __attribute__((weak));
void HardFault_Handler (void) __attribute__((weak));
void MemManage_Handler (void) __attribute__((weak));
void BusFault_Handler (void) __attribute__((weak));
void UsageFault_Handler (void) __attribute__((weak));
void SVC_Handler (void) __attribute__((weak));
void DebugMon_Handler (void) __attribute__((weak));
void PendSV_Handler (void) __attribute__((weak));
void SysTick_Handler (void) __attribute__((weak));

void SUPC_IRQHandler (void) __attribute__((weak));
void RSTC_IRQHandler (void) __attribute__((weak));
void RTC_IRQHandler (void) __attribute__((weak));
void RTT_IRQHandler (void) __attribute__((weak));
void WDT_IRQHandler (void) __attribute__((weak));
void PMC_IRQHandler (void) __attribute__((weak));
void EFC0_IRQHandler (void) __attribute__((weak));
void EFC1_IRQHandler (void) __attribute__((weak));
void DBGU_IRQHandler (void) __attribute__((weak));
void HSMC4_IRQHandler (void) __attribute__((weak));
void PIOA_IRQHandler (void) __attribute__((weak));
void PIOB_IRQHandler (void) __attribute__((weak));
void PIOC_IRQHandler (void) __attribute__((weak));
void USART0_IRQHandler (void) __attribute__((weak));
void USART1_IRQHandler (void) __attribute__((weak));
void USART2_IRQHandler (void) __attribute__((weak));
void USART3_IRQHandler (void) __attribute__((weak));
void MCI0_IRQHandler (void) __attribute__((weak));
void TWI0_IRQHandler (void) __attribute__((weak));
void TWI1_IRQHandler (void) __attribute__((weak));
void SPI0_IRQHandler (void) __attribute__((weak));
void SSC0_IRQHandler (void) __attribute__((weak));
void TC0_IRQHandler (void) __attribute__((weak));
void TC1_IRQHandler (void) __attribute__((weak));
void TC2_IRQHandler (void) __attribute__((weak));
void PWM_IRQHandler (void) __attribute__((weak));
void ADCC0_IRQHandler (void) __attribute__((weak));
void ADCC1_IRQHandler (void) __attribute__((weak));
void HDMA_IRQHandler (void) __attribute__((weak));
void USBD_IRQHandler (void) __attribute__((weak));

/*=========================================================================*/
/*  DEFINE: All code exported                                              */
/*=========================================================================*/
/*
 * This is our vector table.
 */
__attribute__ ((section(".vectors"), used))
void (* const gVectors[])(void) = 
{
   (void (*)(void))((unsigned long)&_estack),
   ResetHandler,
   NMI_Handler,
   HardFault_Handler,
   MemManage_Handler,
   BusFault_Handler,
   UsageFault_Handler,
   0, 0, 0, 0,
   SVC_Handler,
   DebugMon_Handler,
   0,
   PendSV_Handler,
   SysTick_Handler,
   
   SUPC_IRQHandler,     /* 0  SUPPLY CONTROLLER */
   RSTC_IRQHandler,     /* 1  RESET CONTROLLER */
   RTC_IRQHandler,      /* 2  REAL TIME CLOCK */
   RTT_IRQHandler,      /* 3  REAL TIME TIMER */
   WDT_IRQHandler,      /* 4  WATCHDOG TIMER */
   PMC_IRQHandler,      /* 5  PMC */
   EFC0_IRQHandler,     /* 6  EFC0 */
   EFC1_IRQHandler,     /* 7  EFC1 */
   DBGU_IRQHandler,     /* 8  DBGU */
   HSMC4_IRQHandler,    /* 9  HSMC4 */
   PIOA_IRQHandler,     /* 10 Parallel IO Controller A */
   PIOB_IRQHandler,     /* 11 Parallel IO Controller B */
   PIOC_IRQHandler,     /* 12 Parallel IO Controller C */
   USART0_IRQHandler,   /* 13 USART 0 */
   USART1_IRQHandler,   /* 14 USART 1 */
   USART2_IRQHandler,   /* 15 USART 2 */
   USART3_IRQHandler,   /* 16 USART 3 */
   MCI0_IRQHandler,     /* 17 Multimedia Card Interface */
   TWI0_IRQHandler,     /* 18 TWI 0 */
   TWI1_IRQHandler,     /* 19 TWI 1 */
   SPI0_IRQHandler,     /* 20 Serial Peripheral Interface */
   SSC0_IRQHandler,     /* 21 Serial Synchronous Controller 0 */
   TC0_IRQHandler,      /* 22 Timer Counter 0 */
   TC1_IRQHandler,      /* 23 Timer Counter 1 */
   TC2_IRQHandler,      /* 24 Timer Counter 2 */
   PWM_IRQHandler,      /* 25 Pulse Width Modulation Controller */
   ADCC0_IRQHandler,    /* 26 ADC controller0 */
   ADCC1_IRQHandler,    /* 27 ADC controller1 */
   HDMA_IRQHandler,     /* 28 HDMA */
   USBD_IRQHandler,     /* 29 USB Device High Speed UDP_HS */
   0                    /* 30 not used */
}; /* gVectors */

/*
 * And here are the weak interrupt handlers.
 */
void NMI_Handler (void) { while(1); }
void HardFault_Handler (void) { while(1); }
void MemManage_Handler (void) { while(1); }
void BusFault_Handler (void) { while(1); }
void UsageFault_Handler (void) { while(1); }
void SVC_Handler (void) { while(1); }
void DebugMon_Handler (void) { while(1); }
void PendSV_Handler (void) { while(1); }
void SysTick_Handler (void) { while(1); }

void SUPC_IRQHandler (void) { while(1); }
void RSTC_IRQHandler (void) { while(1); }
void RTC_IRQHandler (void) { while(1); }
void RTT_IRQHandler (void) { while(1); }
void WDT_IRQHandler (void) { while(1); }
void PMC_IRQHandler (void) { while(1); }
void EFC0_IRQHandler (void) { while(1); }
void EFC1_IRQHandler (void) { while(1); }
void DBGU_IRQHandler (void) { while(1); }
void HSMC4_IRQHandler (void) { while(1); }
void PIOA_IRQHandler (void) { while(1); }
void PIOB_IRQHandler (void) { while(1); }
void PIOC_IRQHandler (void) { while(1); }
void USART0_IRQHandler (void) { while(1); }
void USART1_IRQHandler (void) { while(1); }
void USART2_IRQHandler (void) { while(1); }
void USART3_IRQHandler (void) { while(1); }
void MCI0_IRQHandler (void) { while(1); }
void TWI0_IRQHandler (void) { while(1); }
void TWI1_IRQHandler (void) { while(1); }
void SPI0_IRQHandler (void) { while(1); }
void SSC0_IRQHandler (void) { while(1); }
void TC0_IRQHandler (void) { while(1); }
void TC1_IRQHandler (void) { while(1); }
void TC2_IRQHandler (void) { while(1); }
void PWM_IRQHandler (void) { while(1); }
void ADCC0_IRQHandler (void) { while(1); }
void ADCC1_IRQHandler (void) { while(1); }
void HDMA_IRQHandler (void) { while(1); }
void USBD_IRQHandler (void) { while(1); }

/*** EOF ***/
